@@ -52,7 +52,7 @@ from ..enums import AppCommandOptionType, AppCommandType, ChannelType, Locale
 from .models import Choice
 from .transformers import annotation_to_parameter, CommandParameter, NoneType
 from .errors import AppCommandError, CheckFailure, CommandInvokeError, CommandSignatureMismatch, CommandAlreadyRegistered
-from .translator import TranslationContext, TranslationContextLocation, Translator, locale_str
+from .translator import TranslationContextLocation, TranslationContext, Translator, locale_str
 from ..message import Message
 from ..user import User
 from ..member import Member
@@ -492,10 +492,17 @@ class Parameter:
     default: Any
         The default value of the parameter, if given.
         If not given then this is :data:`~discord.utils.MISSING`.
+    command: :class:`Command`
+        The command this parameter is attached to.
     """
 
-    def __init__(self, parent: CommandParameter) -> None:
+    def __init__(self, parent: CommandParameter, command: Command[Any, ..., Any]) -> None:
         self.__parent: CommandParameter = parent
+        self.__command: Command[Any, ..., Any] = command
+
+    @property
+    def command(self) -> Command[Any, ..., Any]:
+        return self.__command
 
     @property
     def name(self) -> str:
@@ -505,6 +512,10 @@ class Parameter:
     def display_name(self) -> str:
         return self.__parent.display_name
 
+    @property
+    def required(self) -> bool:
+        return self.__parent.required
+
     @property
     def description(self) -> str:
         return str(self.__parent.description)
@@ -756,7 +767,7 @@ class Command(Generic[GroupT, P, T]):
         base['name_localizations'] = name_localizations
         base['description_localizations'] = description_localizations
         base['options'] = [
-            await param.get_translated_payload(translator, Parameter(param)) for param in self._params.values()
+            await param.get_translated_payload(translator, Parameter(param, self)) for param in self._params.values()
         ]
         return base
 
@@ -774,7 +785,7 @@ class Command(Generic[GroupT, P, T]):
         if self.parent is None:
             base['nsfw'] = self.nsfw
             base['dm_permission'] = not self.guild_only
-            base['default_member_permissions'] = self.default_permissions and self.default_permissions.value
+            base['default_member_permissions'] = None if self.default_permissions is None else self.default_permissions.value
 
         return base
 
@@ -911,6 +922,19 @@ class Command(Generic[GroupT, P, T]):
     def _get_internal_command(self, name: str) -> Optional[Union[Command, Group]]:
         return None
 
+    @property
+    def parameters(self) -> List[Parameter]:
+        """Returns a list of parameters for this command.
+
+        This does not include the ``self`` or ``interaction`` parameters.
+
+        Returns
+        --------
+        List[:class:`Parameter`]
+            The parameters of this command.
+        """
+        return [Parameter(p, self) for p in self._params.values()]
+
     def get_parameter(self, name: str) -> Optional[Parameter]:
         """Retrieves a parameter by its name.
 
@@ -930,7 +954,7 @@ class Command(Generic[GroupT, P, T]):
 
         parent = self._params.get(name)
         if parent is not None:
-            return Parameter(parent)
+            return Parameter(parent, self)
         return None
 
     @property
@@ -1246,7 +1270,7 @@ class ContextMenu:
             'name': self.name,
             'type': self.type.value,
             'dm_permission': not self.guild_only,
-            'default_member_permissions': self.default_permissions and self.default_permissions.value,
+            'default_member_permissions': None if self.default_permissions is None else self.default_permissions.value,
             'nsfw': self.nsfw,
         }
 
@@ -1678,7 +1702,7 @@ class Group:
         if self.parent is None:
             base['nsfw'] = self.nsfw
             base['dm_permission'] = not self.guild_only
-            base['default_member_permissions'] = self.default_permissions and self.default_permissions.value
+            base['default_member_permissions'] = None if self.default_permissions is None else self.default_permissions.value
 
         return base
 
